<?php

/**
 * @file
 * Admin page callbacks for the tournaments_series module.
 */

/**
 * Settings form as implemented by menu.
 */
function tournaments_series_admin_settings($form, &$form_state) {
  $form['tournaments_series_block_count'] = array(
    '#type' => 'textfield',
    '#description' => t('The total number of independent tournaments series blocks you want. Enter a number between 0 and 99. If you set this to 0, you will have no blocks created but you can still use "standings" page directly.'),
    '#default_value' => variable_get('tournaments_series_block_count', '2'),
    '#size' => 2,
  );

  // Custom validation to make sure the user is entering numbers.
  $form['#validate'][] = 'tournaments_series_settings_validate';

  return system_settings_form($form);
}

/**
 * Custom validation for the settings form.
 */
function tournaments_series_settings_validate($form, &$form_state) {
  $number = $form_state['values']['tournaments_series_block_count'];
  // Check to make sure it is a number and that is a maximum of 2 digits.
  if (!is_numeric($number) || strlen($number) > 2) {
    form_set_error('tournaments_series_block_count', t('You must enter a number from 0 to 99.'));
  }
}

/**
 * The table with the list of all tournaments is loaded
 * in the TOURNAMENTS tab on the menu, path "admin/tournaments_series",
 * from data base table "tournaments_series_tournaments".
 *
 * New tournaments can be added and edited in this menu tab.
 *
 * @return array
 *   theme table with the list of tournaments
 */
function tournaments_series_tournaments() {
  $query = db_select('tournaments_series_tournaments', 'st')
      ->extend('PagerDefault')
      ->fields('st')
      ->orderBy('id', 'DESC')
      ->limit(50);
  $rows = array();
  $result = $query->execute();
  if ($result->rowCount()) {
    foreach ($result as $row) {
      $rows[] = array(
        $row->id,
        check_plain($row->name),
        check_plain($row->played),
        theme(
          'item_list', array(
            'items' => array(
              l(t('edit'), 'admin/tournaments-series/tournaments/' . $row->id . '/edit', array('query' => array('destination' => 'admin/tournaments-series/tournaments'))),
              l(t('delete'), 'admin/tournaments-series/tournaments/' . $row->id . '/delete', array('query' => array('destination' => 'admin/tournaments-series/tournaments'))),
            ),
            'attributes' => array(
              'class' => array('links', 'inline'),
            ),
          )
        ),
      );
    }
  }
  $header = array(t('Id'), t('Name'), t('Played'), t('Options'));
  $output = theme('table',
    array(
      'header' => $header,
      'rows' => $rows,
      'empty' => t('No data'),
    )
  ) . theme('pager');
  return $output;
}

/**
 * The table with the list of all tournaments is loaded
 * in the SERIES tab on the menu, path "admin/tournaments_series/series",
 * from data base table "tournaments_series_series".
 *
 * New series can be added and edited in this menu tab.
 *
 * @return array
 *   theme table with the list of series
 */
function tournaments_series_series() {
  $query = db_select('tournaments_series_series', 'ss')
      ->extend('PagerDefault')
      ->fields('ss')
      ->orderBy('id', 'DESC')
      ->limit(15);
  $result = $query->execute();
  $rows = array();
  if ($result->rowCount()) {
    foreach ($result as $row) {
      $rows[] = array(
        $row->id,
        check_plain($row->name),
        $row->rid,
        theme('item_list', array(
          'items' => array(
            l(t('edit'), 'admin/tournaments-series/series/' . $row->id . '/edit', array('query' => array('destination' => 'admin/tournaments-series/series'))),
            l(t('delete'), 'admin/tournaments-series/series/' . $row->id . '/delete', array('query' => array('destination' => 'admin/tournaments-series/series'))),
          ),
          'attributes' => array(
            'class' => array('links', 'inline'),
          ),
            )
        ),
      );
    }
  }
  $header = array(t('Id'), t('Name'), t('Rules'), t('Operations'));
  $output = theme('table',
    array(
      'header' => $header,
      'rows' => $rows,
      'empty' => t('No data'),
    )
  ) . theme('pager');
  return $output;
}

/**
 * The table with the list of all rules is loaded
 * in the RULES tab on the menu, path "admin/tournaments_series/rules",
 * from data base table "tournaments_series_rules".
 *
 * New rules can be added and edited in this menu tab.
 *
 * @return array
 *   theme table with the list of rules
 */
function tournaments_series_rules() {
  $query = db_select('tournaments_series_rules', 'sr')
      ->extend('PagerDefault')
      ->fields('sr')
      ->orderBy('id', 'DESC')
      ->limit(15);
  $result = $query->execute();
  $rows = array();
  if ($result->rowCount()) {
    foreach ($result as $row) {
      $rows[] = array(
        $row->id,
        check_plain($row->name),
        check_plain($row->description),
        theme(
          'item_list', array(
            'items' => array(
              l(t('edit'), 'admin/tournaments-series/rules/' . $row->id . '/edit', array('query' => array('destination' => 'admin/tournaments-series/rules'))),
              l(t('delete'), 'admin/tournaments-series/rules/' . $row->id . '/delete', array('query' => array('destination' => 'admin/tournaments-series/rules'))),
            ),
            'attributes' => array(
              'class' => array('links', 'inline'),
            ),
          )
        ),
      );
    }
  }
  $header = array(t('Id'), t('Name'), t('Description'), t('Operations'));
  $output = theme('table',
    array(
      'header' => $header,
      'rows' => $rows,
      'empty' => t('No data'),
    )
  ) . theme('pager');
  return $output;
}

/**
 * The table with the list of all players is loaded
 * in the PLAYERS tab on the menu, path "admin/tournaments_series/players",
 * from data base table "tournaments_series_players".
 *
 * New player can be added and edited in this menu tab.
 *
 * @return array
 *   theme table with the list of players
 */
function tournaments_series_players() {
  $query = db_select('tournaments_series_players', 'sp')
      ->extend('PagerDefault')
      ->fields('sp')
      ->orderBy('id', 'DESC')
      ->limit(50);
  $result = $query->execute();
  $rows = array();
  if ($result->rowCount()) {
    foreach ($result as $row) {
      $rows[] = array(
        check_plain($row->player),
        check_plain($row->club),
        check_plain($row->nation),
        theme(
          'item_list', array(
            'items' => array(
              l(t('edit'), 'admin/tournaments-series/players/' . $row->id . '/edit', array('query' => array('destination' => 'admin/tournaments-series/players'))),
              l(t('delete'), 'admin/tournaments-series/players/' . $row->id . '/delete', array('query' => array('destination' => 'admin/tournaments-series/players'))),
            ),
            'attributes' => array(
              'class' => array('links', 'inline'),
            ),
          )
        ),
      );
    }
  }
  $header = array(t('Name'), t('Club'), t('Nation'), t('Operations'));
  $output = theme('table',
    array(
      'header' => $header,
      'rows' => $rows,
      'empty' => t('No data'),
    )
  ) . theme('pager');
  return $output;
}

/**
 * Form for delete confirm.
 */
function tournaments_series_delete_confirm($form, &$form_state, $arg) {
  $question = t('Are you sure');
  $path = $arg['path'];
  $description = t('This action cannot be undone.');
  $yes = t('Delete');
  $no = t('Cancel');
  $form_state['tournaments_series_arguments'] = $arg;
  return confirm_form($form, $question, $path, $description, $yes, $no);
}

/**
 * Form for tournament's input.
 *
 * @param array $form
 *   "@param" is drupal default data
 *
 * @param array $form_submit
 *   "@param" is drupal default data
 *
 * @param array $tournament
 *   "@param" is array with tournaments' data
 *   and is used when editing "tournaments_series_add_tournaments_form" form.
 *   If  "$tournament['id']" is empty, then the form is empty too,
 *   because it then means that you add a new tournament.
 */
function tournaments_series_add_tournaments_form($form, &$form_submit, $tournament = '') {
  if (isset($tournament['id'])) {
    $form['tournaments_series_id'] = array(
      '#type' => 'hidden',
      '#default_value' => $tournament['id'],
    );
  }
  $form['tournaments_series_tournament'] = array(
    '#type' => 'textfield',
    '#title' => t('Name of tournament'),
    '#default_value' => isset($tournament['name']) ? $tournament['name'] : '',
    '#required' => TRUE,
  );
  // Load array of all series names and ids.
  $series = tournaments_series_helper_load_names('tournaments_series_series');
  $form['tournaments_series_series'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Series'),
    '#default_value' => isset($tournament['series']) ? $tournament['series'] : array(0),
    '#description' => t('Select series.'),
    '#options' => $series,
    '#required' => FALSE,
  );
  $form['tournaments_series_played'] = array(
    '#type' => 'radios',
    '#title' => t('Played'),
    '#default_value' => 'notplayed',
    '#default_value' => isset($tournament['played']) ? $tournament['played'] : '0',
    '#options' => array(
      '0' => t('Tournament is not played yet'),
      '1' => t('Tournament is played'),
    ),
    '#description' => t('Check if is played.'),
    '#required' => FALSE,
  );
  $ranking_array = array();
  if (isset($tournament['ranking']) && $tournament['played']) {
    $ranking_ids = $tournament['ranking'];
    foreach ($ranking_ids as $i) {
      $query = db_select('tournaments_series_players', 'sp')
          ->condition('id', $i)
          ->fields('sp');
      $result = $query->execute();

      foreach ($result as $row) {
        $ranking_array[] = $row->player;
      }
    }
    $ranking = tournaments_series_helper_implode_textarea($ranking_array);
  }
  else {
    $ranking = '';
  }
  $form['tournaments_series_ranking'] = array(
    '#type' => 'textarea',
    '#title' => t('Ranking'),
    '#description' => t('Each row is for each position.'),
    '#default_value' => $ranking,
    '#states' => array(
      'visible' => array(
        ':input[name="tournaments_series_played"]' => array('value' => '1'),
      ),
    ),
    '#required' => FALSE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save tournament'),
  );
  return $form;
}

/**
 * Form for series' input.
 *
 * @param array $form
 *   "@param" is drupal default data
 *
 * @param array $form_submit
 *   "@param" is drupal default data
 *
 * @param array $series
 *   "@param" is array with series' data
 *   and is used when editing "tournaments_series_add_series_form" form.
 *   If  "$series['id']" is empty, then the form is empty too,
 *   because it then means that you add a new serie.
 */
function tournaments_series_add_series_form($form, &$form_submit, $series = '') {
  if (isset($series['id'])) {
    $form['tournaments_series_id'] = array(
      '#type' => 'hidden',
      '#default_value' => $series['id'],
    );
  }
  $form['tournaments_series_series'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#default_value' => isset($series['name']) ? $series['name'] : '',
    '#description' => t('Name of series, e.g. First seazon 2001/2002.'),
    '#required' => TRUE,
  );
  // Load array of all rules name and ids.
  $rules = tournaments_series_helper_load_names('tournaments_series_rules');

  $form['tournaments_series_rules'] = array(
    '#type' => 'select',
    '#title' => t('Rule'),
    '#description' => t('Select rule.'),
    '#default_value' => isset($series['rid']) ? $series['rid'] : '',
    '#options' => $rules,
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save series'),
  );
  return ($form);
}

/**
 * Form for rules' input.
 *
 * @param array $form
 *   "@param" is drupal default data
 *
 * @param array $form_state
 *   "@param" is drupal default data
 *
 * @param array $rules
 *   "@param" is array with rules' data
 *   and is used when editing "tournaments_series_add_rules_form" form.
 *   If  "$rules['id']" is empty, then the form is empty too,
 *   because it then means that you add a new rule.
 */
function tournaments_series_add_rules_form($form, &$form_state, $rules = '') {
  if (isset($rules['id'])) {
    $form['tournaments_series_id'] = array(
      '#type' => 'hidden',
      '#default_value' => $rules['id'],
    );
  }
  else {
    $rules['options']['1']['rule'] = 0;
    $rules['options']['1']['count'] = 0;
    $rules['options']['1']['from'] = 0;
  }

  $form['tournaments_series_rules'] = array(
    '#type' => 'textfield',
    '#title' => t('Rule'),
    '#default_value' => isset($rules['name']) ? $rules['name'] : '',
    '#description' => t('Name of the rule.'),
    '#required' => TRUE,
  );

  $form['tournaments_series_description'] = array(
    '#type' => 'textfield',
    '#title' => t('Description'),
    '#default_value' => isset($rules['description']) ? $rules['description'] : '',
    '#description' => t('Description of the rule.'),
    '#required' => FALSE,
  );
  $form['tournaments_series_points'] = array(
    '#type' => 'textarea',
    '#title' => t('Points'),
    '#default_value' => isset($rules['points']) ? tournaments_series_helper_implode_textarea($rules['points']) : '',
    '#description' => t('Points are inserted only in numerals. In each row the position points are inserted, going from up to bottom. Each row is for each position.'),
    '#required' => TRUE,
  );
  $form['tournaments_series_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Ranking options'),
    '#prefix' => '<div id="options_div">',
    '#suffix' => '</div>',
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $default = 1;
  $default = $rules['options'] ? count($rules['options']) : $default;
  $form['tournaments_series_options']['tournaments_series_count_sets'] = array(
    '#type' => 'select',
    '#title' => t('Number of ranking options'),
    '#description' => t('Select how many ranking options you want.'),
    '#options' => drupal_map_assoc(array(
      1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
    )),
    '#required' => TRUE,
    '#default_value' => $default,
    '#ajax' => array(
      'callback' => 'tournaments_series_ajax_callback',
      'wrapper' => 'options_div',
    ),
  );
  $max = !empty($form_state['values']['tournaments_series_count_sets']) ? $form_state['values']['tournaments_series_count_sets'] : $default;
  for ($i = 1; $i <= $max; $i++) {
    $_title = 'Ranking options No ' . $i;
    $form['tournaments_series_options']["tournaments_series_set$i"] = array(
      '#type' => 'fieldset',
      '#title' => filter_xss($_title),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    // Here you can add more options.
    $form['tournaments_series_options']["tournaments_series_set$i"]["rule$i"] = array(
      '#type' => 'select',
      '#title' => t('Rule'),
      '#description' => t('Select type of rules'),
      '#options' => tournaments_series_ranking_options_array(),
      '#default_value' => ($rules['options'][$i]['rule']) ? $rules['options'][$i]['rule'] : '0',
      '#required' => TRUE,
    );
    $form['tournaments_series_options']["tournaments_series_set$i"]["rule_count$i"] = array(
      '#type' => 'textfield',
      '#title' => t('Number of included results'),
      '#default_value' => ($rules['options'][$i]['count']) ? $rules['options'][$i]['count'] : '0',
      '#description' => t('Insert how many best results it should count, if it is 0 than it equals all (0=all).'),
      '#required' => TRUE,
      '#states' => array(
        'visible' => array(
          ':input[name="rule' . $i . '"]' => array('value' => 'sum'),
        ),
      ),
    );
    $form['tournaments_series_options']["tournaments_series_set$i"]["rule_from$i"] = array(
      '#type' => 'textfield',
      '#title' => t('From'),
      '#description' => t('Begins from which best results it should count.'),
      '#default_value' => ($rules['options'][$i]['from']) ? $rules['options'][$i]['from'] : '1',
      '#required' => TRUE,
      '#states' => array(
        'visible' => array(
          ':input[name="rule' . $i . '"]' => array('value' => 'sum'),
        ),
      ),
    );
  }
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save rules'),
  );
  return ($form);
}

/**
 * Form for players' input.
 *
 * @param array $form
 *   "@param" is drupal default data
 *
 * @param array $form_submit
 *   "@param" is drupal default data
 *
 * @param array $player
 *   "@param" is array with player data
 *   and is used when editing "tournaments_series_add_players_form" form.
 *   If  "$player['id']" is empty, then the form is empty too,
 *   because it then means that you add a new player.
 */
function tournaments_series_add_players_form($form, &$form_submit, $player = '') {
  if (isset($player['id'])) {
    $form['tournaments_series_id'] = array(
      '#type' => 'hidden',
      '#default_value' => $player['id'],
    );
  }
  $form['tournaments_series_player'] = array(
    '#type' => 'textfield',
    '#title' => t('Player'),
    '#description' => t('Input name and surname.'),
    '#default_value' => isset($player['player']) ? $player['player'] : '',
    '#required' => TRUE,
  );
  $form['tournaments_series_club'] = array(
    '#type' => 'textfield',
    '#title' => t('Club'),
    '#description' => t('Name of the club.'),
    '#default_value' => isset($player['club']) ? $player['club'] : '',
    '#required' => FALSE,
  );
  // IOC Codes.
  $form['tournaments_series_nation'] = array(
    '#type' => 'select',
    '#options' => tournaments_series_helper_ioc_codes(),
    '#title' => t('Nation'),
    '#description' => t('Choose nation.'),
    '#default_value' => isset($player['nation']) ? $player['nation'] : '',
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save player'),
  );
  return $form;
}

/**
 * Ajax for adding or subtracting ranking options.
 *
 * @param array $form
 *   "@param" is drupal default data
 *
 * @param array $form_state
 *   "@param" is drupal default data
 */
function tournaments_series_ajax_callback($form, $form_state) {
  return $form['tournaments_series_options'];
}

/**
 * Tournament is added before editing the form for tournament input.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a tournament that will be edited.
 */
function tournaments_series_edit_tournaments($arg3) {
  if (is_numeric($arg3)) {
    $query = db_select('tournaments_series_tournaments', 'st')
        ->fields('st');
    $query->condition('id', $arg3);
    $result = $query->execute();
    foreach ($result as $row) {
      $tournament['id'] = $row->id;
      $tournament['name'] = check_plain($row->name);
      $tournament['ranking'] = tournaments_series_check_plain_array(unserialize($row->ranking));
      $tournament['series'] = tournaments_series_check_plain_array(unserialize($row->series));
      $tournament['played'] = check_plain($row->played);
    }
    if ($result->rowCount()) {
      $build = array(
        'edit_form' => drupal_get_form('tournaments_series_add_tournaments_form', $tournament),
      );
      return $build;
    }
    else {
      return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Player is added before editing the form for player input.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a player that will be edited.
 */
function tournaments_series_edit_players($arg3) {
  if (is_numeric($arg3)) {
    $query = db_select('tournaments_series_players', 'sp')
        ->fields('sp');
    $query->condition('id', $arg3);
    $result = $query->execute();
    foreach ($result as $row) {
      $player['id'] = $row->id;
      $player['player'] = check_plain($row->player);
      $player['club'] = check_plain($row->club);
      $player['nation'] = check_plain($row->nation);
    }
    if ($result->rowCount()) {
      $build = array(
        'edit_form' => drupal_get_form('tournaments_series_add_players_form', $player),
      );
      return $build;
    }
    else {
      return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Rules is added before editing the form for rules input.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a rule that will be edited.
 */
function tournaments_series_edit_rules($arg3) {
  if (is_numeric($arg3)) {
    $query = db_select('tournaments_series_rules', 'sr')
        ->fields('sr');
    $query->condition('id', $arg3);
    $result = $query->execute();
    foreach ($result as $row) {
      $rules['id'] = $row->id;
      $rules['name'] = check_plain($row->name);
      $rules['description'] = check_plain($row->description);
      $rules['points'] = tournaments_series_check_plain_array(unserialize($row->points));
      $rules['options'] = unserialize($row->options);
    }
    if ($result->rowCount()) {
      $build = array(
        'edit_form' => drupal_get_form('tournaments_series_add_rules_form', $rules),
      );
      return $build;
    }
    else {
      return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Series is added before editing the form for series input.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a serie that will be edited.
 */
function tournaments_series_edit_series($arg3) {
  if (is_numeric($arg3)) {
    $query = db_select('tournaments_series_series', 'ss')
        ->fields('ss');
    $query->condition('id', $arg3);
    $result = $query->execute();
    foreach ($result as $row) {
      $series['id'] = $row->id;
      $series['name'] = check_plain($row->name);
      $series['rid'] = $row->rid;
    }
    if ($result->rowCount()) {
      $build = array(
        'edit_form' => drupal_get_form('tournaments_series_add_series_form', $series),
      );
      return $build;
    }
    else {
      return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Delete tournament.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a tournament that will be deleted.
 */
function tournaments_series_delete_tournaments($arg3) {
  $arg['path'] = 'admin/tournaments_series/tournaments';
  $arg['db_table'] = 'tournaments_series_tournaments';
  if (is_numeric($arg3)) {
    $arg['id'] = $arg3;
    $query = db_select('tournaments_series_tournaments', 'st')
        ->fields('st');
    $query->condition('id', $arg3);
    $result = $query->execute();
    $row = $result->fetch();
    if ($result->rowCount() && !$row->played) {
      $build = array(
        'delete_form' => drupal_get_form('tournaments_series_delete_confirm', $arg),
      );
      return $build;
    }
    else {
      return drupal_set_message(t('The tournament cannot be deleted if it was played.'), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Delete player.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a player that will be deleted.
 */
function tournaments_series_delete_players($arg3) {
  $arg['path'] = 'admin/tournaments_series/players';
  $arg['db_table'] = 'tournaments_series_players';
  if (is_numeric($arg3)) {
    $arg['id'] = $arg3;
    $query = db_select('tournaments_series_players', 'sp')
        ->fields('sp');
    $query->condition('id', $arg3);
    $result = $query->execute();
    if ($result->rowCount() && !tournaments_series_helper_played($arg3)) {
      $build = array(
        'delete_form' => drupal_get_form('tournaments_series_delete_confirm', $arg),
      );
      return $build;
    }
    else {
      return drupal_set_message(t('The player cannot be deleted if he played.'), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Delete rule.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a rule that will be deleted.
 */
function tournaments_series_delete_rules($arg3) {
  $arg['path'] = 'admin/tournaments_series/rules';
  $arg['db_table'] = 'tournaments_series_rules';
  if (is_numeric($arg3)) {
    $arg['id'] = $arg3;
    $query = db_select('tournaments_series_rules', 'sr')
        ->fields('sr');
    $query->condition('id', $arg3);
    $result = $query->execute();

    if ($result->rowCount()) {
      $query_2 = db_select('tournaments_series_series', 'ts')
          ->fields('ts');

      $query_2->condition('rid', $arg3);
      $result_2 = $query_2->execute();
      if (!$result_2->rowCount()) {
        $build = array(
          'delete_form' => drupal_get_form('tournaments_series_delete_confirm', $arg),
        );
        return $build;
      }
      else {
        return drupal_set_message(t("You cannot delete the rule that is used"), 'error');
      }
    }
    else {
      return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Delete series.
 *
 * @param int $arg3
 *   "@param" is the third argument in the menu-path that calls this function.
 *   It defines the id of a series that will be deleted.
 */
function tournaments_series_delete_series($arg3) {
  $arg['path'] = 'admin/tournaments_series/series';
  $arg['db_table'] = 'tournaments_series_series';
  if (is_numeric($arg3)) {
    $arg['id'] = $arg3;
    $query = db_select('tournaments_series_series', 'ss')
        ->fields('ss');
    $query->condition('id', $arg3);
    $result = $query->execute();
    if ($result->rowCount()) {
      $build = array(
        'delete_form' => drupal_get_form('tournaments_series_delete_confirm', $arg),
      );
      return $build;
    }
    else {
      return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
    }
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Validation for tournaments_series_add_players_form().
 */
function tournaments_series_add_players_form_validate($form, &$form_state) {
  $player = $form_state['values']['tournaments_series_player'];
  $saved_players = tournaments_series_helper_load_players_names();
  if (in_array($player, $saved_players) && !isset($form_state['values']['tournaments_series_id'])) {
    form_set_error('tournaments_series_player', t('The player "@player" is already registered.', array('@player' => $player)));
  }
}

/**
 * Validation for tournaments_series_add_rules_form().
 */
function tournaments_series_add_rules_form_validate($form, &$form_state) {
  $points = tournaments_series_helper_explode_textarea($form_state['values']['tournaments_series_points']);
  $_e = FALSE;
  foreach ($points as $point) {
    if (!is_numeric($point) || $point < 0) {
      $_e = TRUE;
    }
  }
  if ($_e) {
    form_set_error('tournaments_series_points', t('The points have to be positive numbers'));
  }
  $count_sets = $form_state['values']['tournaments_series_count_sets'];
  for ($i = 1; $i <= $count_sets; $i++) {
    if (!is_numeric($form_state['values']['rule_count' . $i]) || $form_state['values']['rule_count' . $i] < 0) {
      form_set_error($form_state['values']['rule_count' . $i], ' It has to be a positive number' . $form_state['values']['rule_count' . $i]);
    }
    if (!is_numeric($form_state['values']['rule_from' . $i]) || $form_state['values']['rule_from' . $i] < 1) {
      form_set_error($form_state['values']['rule_from' . $i], 'It has to be a greather from 0' . $form_state['values']['rule_from' . $i]);
    }
  }
}

/**
 * Validation for tournaments_series_add_tournaments_form().
 */
function tournaments_series_add_tournaments_form_validate($form, &$form_state) {
  if ($form_state['values']['tournaments_series_played'] == '1') {
    $players = tournaments_series_helper_explode_textarea($form_state['values']['tournaments_series_ranking']);
    $saved_players = tournaments_series_helper_load_players_names();
    $controled = array();
    $doubles = array_count_values($players);
    foreach ($players as $player) {
      $controled[$player] = in_array($player, $saved_players);
    }
    if (in_array(FALSE, $controled)) {
      $_e = t('List of errors:');
      $_e .= '<ul>';
      $line = 0;
      foreach ($controled as $key => $c) {
        $line++;
        if (!$c) {
          $_e .= '<li>';
          $key = empty($key) ? t('You left a space or pressed "enter" more than needed on line: @line', array('@line' => $line)) : t('Player @key on line :@line, is not in the base or is wrong written.', array('@key' => $key, '@line' => $line));
          $_e .= $key;
          $_e .= '</li>';
        }
      }
      $_e .= '</ul>';
      form_set_error('tournaments_series_ranking', $_e);
    }
    foreach ($doubles as $player => $double) {
      if ($double > 1) {
        form_set_error('tournaments_series_ranking', t('Player "@player" is written more than once.', array('@player' => $player)));
        break;
      }
    }
  }
}

/**
 * Form submits.
 */

/**
 * Submit function for tournaments_series_delete_confirm().
 */
function tournaments_series_delete_confirm_submit($form, &$form_state) {

  if (tournaments_series_helper_delete_tournaments_series($form_state['tournaments_series_arguments']['id'], $form_state['tournaments_series_arguments']['db_table'])) {
    return drupal_set_message(t('Data has been deleted.'));
  }
  else {
    return drupal_set_message(t("We're sorry, but an error has occurred"), 'error');
  }
}

/**
 * Submit function for tournaments_series_add_tournaments_form().
 */
function tournaments_series_add_tournaments_form_submit($form, &$form_state) {
  $old_series = array();
  if ($form_state['values']['tournaments_series_played'] == '1') {
    $players = tournaments_series_helper_explode_textarea($form_state['values']['tournaments_series_ranking']);
    $new_players = array();
    foreach ($players as $player) {
      $query = db_select('tournaments_series_players', 'sp')
          ->condition('player', $player)
          ->fields('sp');
      $result = $query->execute();
      foreach ($result as $row) {
        $new_players[] = $row->id;
      }
    }
    $tournament = array(
      'name' => $form_state['values']['tournaments_series_tournament'],
      'series' => serialize($form_state['values']['tournaments_series_series']),
      'ranking' => serialize($new_players),
      'played' => '1',
    );
  }
  else {
    $tournament = array(
      'name' => $form_state['values']['tournaments_series_tournament'],
      'series' => serialize($form_state['values']['tournaments_series_series']),
      'played' => '0',
    );
  }
  if (isset($form_state['values']['tournaments_series_id'])) {
    $tournament['id'] = $form_state['values']['tournaments_series_id'];
  }
  $tid = tournaments_series_helper_insert($tournament, 'tournaments_series_tournaments');
  if ($tid) {
    $tid = isset($form_state['values']['tournaments_series_id']) ? $tournament['id'] : $tid;
    if (isset($tournament['id'])) {
      $old_series = tournaments_series_helper_load_id($tournament['id']);
      db_delete('tournaments_series_tournament_serie')
          ->condition('tid', $tournament['id'])
          ->execute();
    }
    foreach ($form_state['values']['tournaments_series_series'] as $serie) {
      if ($serie) {
        db_insert('tournaments_series_tournament_serie')
            ->fields(array(
              'sid' => $serie,
              'tid' => $tid,
                )
            )
            ->execute();
      }
    }
    drupal_set_message(t('Ok you inserted tournament to base.'));
    // Calculates the ranking for all seasons to which a tournament belongs.
    if (array_sum($form_state['values']['tournaments_series_series'])) {
      $_series = unserialize($tournament['series']);
      foreach ($_series as $_key => $_serie) {
        if (!$_serie) {
          unset($_series[$_key]);
        }
      }
      tournaments_series_helper_standings($_series);
    }
    // Calculates the ranking for all seasons to which a tournament belonged.
    if (array_sum($old_series)) {
      tournaments_series_helper_standings($old_series);
    }
  }
  else {
    drupal_set_message(t('There was no change'), 'warning');
  }
}

/**
 * Submit function for tournaments_series_add_rules_form().
 */
function tournaments_series_add_rules_form_submit($form, &$form_state) {
  $points = tournaments_series_helper_explode_textarea($form_state['values']['tournaments_series_points']);
  $options = array();

  for ($i = 1; $i <= $form_state['values']['tournaments_series_count_sets']; $i++) {
    $options[$i] = array(
      'rule' => $form_state['values']["rule$i"],
      'count' => floor($form_state['values']["rule_count$i"]),
      'from' => floor($form_state['values']["rule_from$i"]),
    );
  }
  $rule = array(
    'name' => $form_state['values']['tournaments_series_rules'],
    'description' => $form_state['values']['tournaments_series_description'],
    'points' => serialize($points),
    'options' => serialize($options),
  );
  if (isset($form_state['values']['tournaments_series_id'])) {
    $rule['id'] = $form_state['values']['tournaments_series_id'];
  }
  if (tournaments_series_helper_insert($rule, 'tournaments_series_rules')) {
    // Controls if a rules was in series to change the ranking for that series.
    if (isset($form_state['values']['tournaments_series_id'])) {
      $_series = array();
      $result = db_query('SELECT * FROM {tournaments_series_series} WHERE rid = :rid', array(':rid' => $form_state['values']['tournaments_series_id']));
      foreach ($result as $record) {
        $_series[] = $record->id;
      }
      tournaments_series_helper_standings($_series);
    }

    drupal_set_message(t('Ok you inserted a rule. You can use it in your series'));
  }
  else {
    drupal_set_message(t('There was no change'), 'warning');
  }
}

/**
 * Submit function for tournaments_series_add_series_form().
 */
function tournaments_series_add_series_form_submit($form, &$form_state) {
  $series = array(
    'name' => $form_state['values']['tournaments_series_series'],
    'rid' => $form_state['values']['tournaments_series_rules'],
  );
  if (isset($form_state['values']['tournaments_series_id'])) {
    $series['id'] = $form_state['values']['tournaments_series_id'];
  }

  if (tournaments_series_helper_insert($series, 'tournaments_series_series')) {
    if (isset($form_state['values']['tournaments_series_id'])) {
      tournaments_series_helper_standings(array($series['id']));
    }
    drupal_set_message(t('Ok you inserted new series.'));
  }
  else {
    drupal_set_message(t('There was no change'), 'warning');
  }
}

/**
 * Submit function for tournaments_series_add_players_form().
 */
function tournaments_series_add_players_form_submit($form, &$form_state) {
  $player = array(
    'player' => $form_state['values']['tournaments_series_player'],
    'club' => $form_state['values']['tournaments_series_club'],
    'nation' => $form_state['values']['tournaments_series_nation'],
  );

  if (isset($form_state['values']['tournaments_series_id'])) {
    $player['id'] = $form_state['values']['tournaments_series_id'];
  }

  if (tournaments_series_helper_insert($player, 'tournaments_series_players')) {
    drupal_set_message(t('Ok you inserted player to base. You can use it in your tournaments'));
  }
  else {
    drupal_set_message(t('There was no change'), 'warning');
  }
}
